import { __awaiter } from "tslib";
import { FASTElement } from '@microsoft/fast-element';
import { DI, Registration } from '@microsoft/fast-foundation';
import { AlertConfig, defaultAlertConfig } from './config';
/**
 * configure.
 *
 * @remarks
 * Configure the alert micro frontend for host app integration.
 *
 * @example Providing template options to align to your host application.
 * ```ts

 *   const { configure } = await import('@genesislcap/foundation-alerts/config'); // < import from the subpath
 *   return configure({
 *     name: `nexus-app-alerts`,
 *     // These will be merged with the packages `defaultTemplateOptions`. You will need to have these components registered in your application.
 *     templateOptions: {
 *       button: 'nexus-button',
 *       checkbox: 'nexus-checkbox-next',
 *       provider: 'template',
 *     },
 *   });
 * },
 * ```
 *
 * @param config - A partial AlertConfig.
 * @public
 */
export function configure(config) {
    return __awaiter(this, void 0, void 0, function* () {
        /**
         * Merge the configs
         */
        const value = Object.assign(Object.assign({}, defaultAlertConfig), config);
        if (config.templateOptions) {
            value.templateOptions = Object.assign(Object.assign({}, defaultAlertConfig.templateOptions), config.templateOptions);
        }
        /**
         * Register a new AlertConfig
         */
        DI.getOrCreateDOMContainer().register(Registration.instance(AlertConfig, value));
        /**
         * Lazily reference and define the micro frontend element post config setting.
         */
        const { FoundationAlerts, FoundationAlertsTemplate, FoundationAlertsStyles } = yield import('../main');
        const { name, attributes, shadowOptions, elementOptions } = value;
        return FASTElement.define(FoundationAlerts, {
            name,
            template: FoundationAlertsTemplate,
            styles: FoundationAlertsStyles,
            attributes,
            shadowOptions,
            elementOptions,
        });
    });
}
